@@ -364,8 +364,10 @@ class AGServerHelperNTLM(object):
                 "Error while setting permissions information for {} to {}.".format(
                     service, principal))
 
-    def removeServicePermisions(self, folder, service, principal):
-        """Add service permisions
+    def cleanServicePermisions(self, folder, service, principal):
+        """Cleans all permissions that have been assigned to a role (principal). This is typically used when a role is deleted.
+
+        This operation is only available through the Permissions resource on the Root Folder.
 
         Args:
             self: The reserved object 'self'
